@@ -2,10 +2,11 @@ package App::cpm::Worker::Installer;
 use strict;
 use warnings;
 use utf8;
-our $VERSION = '0.914';
+our $VERSION = '0.950';
 
 use App::cpm::Logger::File;
 use App::cpm::Worker::Installer::Menlo;
+use App::cpm::Worker::Installer::Prebuilt;
 use App::cpm::version;
 use CPAN::DistnameInfo;
 use CPAN::Meta;
@@ -20,6 +21,7 @@ use File::Spec;
 use File::Temp ();
 use File::pushd 'pushd';
 use JSON::PP ();
+use Time::HiRes ();
 
 use constant NEED_INJECT_TOOLCHAIN_REQUIREMENTS => $] < 5.016;
 
@@ -97,6 +99,7 @@ sub new {
         $menlo->setup_local_lib($local_lib);
     }
     $menlo->log("--", `$^X -V`, "--");
+    $option{prebuilt} = App::cpm::Worker::Installer::Prebuilt->new if $option{prebuilt};
     bless { %option, menlo => $menlo }, $class;
 }
 
@@ -125,8 +128,9 @@ sub _fetch_git {
 }
 
 sub enable_prebuilt {
-    my ($self, $uri) = @_;
-    $self->{prebuilt} && $TRUSTED_MIRROR->(ref $uri ? $uri->[0] : $uri);
+    my $self = shift;
+    my $uri = ref $_[0] ? $_[0][0] : $_[0];
+    $self->{prebuilt} && !$self->{prebuilt}->skip($uri) && $TRUSTED_MIRROR->($uri);
 }
 
 sub fetch {
@@ -358,6 +362,7 @@ sub _retry {
     my ($self, $sub) = @_;
     return 1 if $sub->();
     return unless $self->{retry};
+    Time::HiRes::sleep(0.1);
     $self->{logger}->log("! Retrying (you can turn off this behavior by --no-retry)");
     return $sub->();
 }
